@@ -47,7 +47,7 @@ module Thin
     def process
       if threaded?
         @request.threaded = true
-        EventMachine.defer(method(:pre_process), method(:post_process))
+        EventMachine.defer { post_process(pre_process) }
       else
         @request.threaded = false
         post_process(pre_process)
@@ -72,6 +72,10 @@ module Thin
       if @backend.ssl?
         @request.env["rack.url_scheme"] = "https"
 
+        if @backend.respond_to?(:port)
+          @request.env['SERVER_PORT'] = @backend.port.to_s
+        end
+
         if cert = get_peer_cert
           @request.env['rack.peer_cert'] = cert
         end
